Clazz.declarePackage("J.adapter.smarter");
(function(){
var c$ = Clazz.decorateAsClass(function(){
this.atomSetIndex = 0;
Clazz.instantialize(this, arguments);}, J.adapter.smarter, "AtomSetObject", null);
})();
;//5.0.1-v4 Fri Sep 06 21:51:44 CDT 2024
